nxp-pac

Crates

git

Versions

mcxn947_cm33_core1

Flavors

MacHwFeature3

Struct MacHwFeature3 

#[repr(transparent)]
pub struct MacHwFeature3(pub u32);
Hardware Features 3

Tuple Fields

0: u32

Implementations

Source

impl MacHwFeature3

pub const fn nrvf(&self) -> Nrvf

Number of Extended VLAN Tag Filters Enabled

pub const fn set_nrvf(&mut self, val: Nrvf)

Number of Extended VLAN Tag Filters Enabled

pub const fn cbtisel(&self) -> bool

Queue/Channel based VLAN tag insertion on Tx Enable

pub const fn set_cbtisel(&mut self, val: bool)

Queue/Channel based VLAN tag insertion on Tx Enable

pub const fn dvlan(&self) -> bool

Double VLAN Tag Processing Selected

pub const fn set_dvlan(&mut self, val: bool)

Double VLAN Tag Processing Selected

pub const fn pdupsel(&self) -> bool

Broadcast/Multicast Packet Duplication

pub const fn set_pdupsel(&mut self, val: bool)

Broadcast/Multicast Packet Duplication

pub const fn frpsel(&self) -> bool

Flexible Receive Parser Selected

pub const fn set_frpsel(&mut self, val: bool)

Flexible Receive Parser Selected

pub const fn frpbs(&self) -> Frpbs

Flexible Receive Parser Buffer size

pub const fn set_frpbs(&mut self, val: Frpbs)

Flexible Receive Parser Buffer size

pub const fn frpes(&self) -> Frpes

Flexible Receive Parser Table Entries size

pub const fn set_frpes(&mut self, val: Frpes)

Flexible Receive Parser Table Entries size

pub const fn estsel(&self) -> bool

Enhancements to Scheduled Traffic Enable

pub const fn set_estsel(&mut self, val: bool)

Enhancements to Scheduled Traffic Enable

pub const fn estdep(&self) -> Estdep

Depth of the Gate Control List

pub const fn set_estdep(&mut self, val: Estdep)

Depth of the Gate Control List

pub const fn estwid(&self) -> Estwid

Width of the Time Interval field in the Gate Control List

pub const fn set_estwid(&mut self, val: Estwid)

Width of the Time Interval field in the Gate Control List

pub const fn fpesel(&self) -> bool

Frame Preemption Enable

pub const fn set_fpesel(&mut self, val: bool)

Frame Preemption Enable

pub const fn tbssel(&self) -> bool

Time Based Scheduling Enable

pub const fn set_tbssel(&mut self, val: bool)

Time Based Scheduling Enable

pub const fn asp(&self) -> Asp

Automotive Safety Package

pub const fn set_asp(&mut self, val: Asp)

Automotive Safety Package